@@ -5,8 +5,8 @@ import time
 from pydantic import BaseModel, PrivateAttr
 from fastapi.encoders import jsonable_encoder
 from dgraph_orm import GQLException
-from .execute import gql
 from devtools import debug
+from dgraph_orm.ACL.client import DgraphClient
 
 
 def d_rez(refresh: bool = False, use_stale: bool = False, returns: T.Type = None):
@@ -162,6 +162,8 @@ class Node(BaseModel):
         url: str
         uid_field_name: str
 
+        dgraph_client: DgraphClient
+
     @property
     def _uid(self) -> T.Union[str, int]:
         return getattr(self, self.GQL.uid_field_name)
@@ -376,11 +378,8 @@ class Node(BaseModel):
         variables = {"input": jsonable_encoder(inputs)}
         if upsert is not None:
             variables["upsert"] = upsert
-        j = await gql(
-            query_str=query_str,
-            variables=variables,
-            url=cls.GQL.url,
-            use_one_time=use_one_time,
+        j = await cls.GQL.dgraph_client.execute(
+            query_str=query_str, variables=variables, use_one_time=True
         )
         node_d_lst = j["data"][f"{cls.GQL.add_function_name}"][
             cls.GQL.payload_node_name
@@ -445,11 +444,12 @@ class Node(BaseModel):
 
         resolver = given_resolver or self._used_resolver
         query_str = resolver.make_update_mutation_str()
-        j = await gql(query_str=query_str, variables=variables, url=self.GQL.url)
+        j = await self.GQL.dgraph_client.execute(
+            query_str=query_str, variables=variables
+        )
         node_d_lst = j["data"][f"{self.GQL.update_function_name}"][
             self.GQL.payload_node_name
         ]
-
         if not node_d_lst:
             # raise Exception("No update was registered!!")
             print("NO UPDATE WAS REGISTERED")
@@ -468,7 +468,9 @@ class Node(BaseModel):
         resolver = given_resolver or self._used_resolver
         query_str = resolver.make_delete_mutation_str()
         variables = {"filter": {self._uid_field_name: self._uid}}
-        j = await gql(query_str=query_str, variables=variables, url=self.GQL.url)
+        j = await self.GQL.dgraph_client.execute(
+            query_str=query_str, variables=variables
+        )
         node_d_lst = j["data"][f"{self.GQL.delete_function_name}"][
             self.GQL.payload_node_name
         ]
