@@ -3,7 +3,6 @@ import typing as T
 import json
 from pydantic import BaseModel, Field
 from fastapi.encoders import jsonable_encoder
-from . import execute
 from dgraph_orm import GQLException
 from .node import Node, Params
 
@@ -142,7 +141,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     async def query(self) -> T.List[NodeType]:
         s = self.make_query_query_str()
-        res = await execute.gql(query_str=s, url=self.node.GQL.url)
+        res = await self.node.GQL.dgraph_client.execute(query_str=s)
         lst: T.List[dict] = res["data"][self.query_query_name()]
         return [self.parse_obj_nested(d) for d in lst]
 
@@ -168,7 +167,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     async def _get(self, kwargs_d: dict) -> T.Optional[NodeType]:
         s = self.make_get_query_str(kwargs_d=kwargs_d)
-        res = await execute.gql(query_str=s, url=self.node.GQL.url)
+        res = await self.node.GQL.dgraph_client.execute(query_str=s)
         obj = res["data"][self.get_query_name()]
         if obj:
             return self.parse_obj_nested(obj)
